# import pytest

from cerebrum_client.client import quote_path_arg, urljoin


def test_quote():
    assert quote_path_arg('foo/bar') == 'foo%2Fbar'


def test_join():
    url = urljoin('https://localhost/foo', 'bar')
    assert url == 'https://localhost/foo/bar'


def test_join_multi():
    url = urljoin('https://localhost/foo', 'bar', 'baz')
    assert url == 'https://localhost/foo/bar/baz'


def test_base_url(endpoints, base_url):
    assert endpoints.baseurl == base_url
    url = endpoints.get_account_url('foo')
    assert url.startswith(base_url)


def test_get_account_url(endpoints, base_url):
    url = endpoints.get_account_url('foo')
    print('got url', url)
    assert url == urljoin(base_url, 'v1/accounts/foo')


def test_get_account_url_escape(endpoints, base_url):
    url = endpoints.get_account_url('foo/bar')
    print('got url', url)
    assert url == urljoin(base_url, 'v1/accounts/foo%2Fbar')
